# opseestools

This is a library to be used with OpenSeesPy.

It includes a collection of analysis functions that are useful if you are analyzing frames or wall buildings both in two and three dimensions, storing the results in Python variables. 
It also includes another useful tools for processing results and creating scripts

## Installation

pip install opseestools

## Citation

You can cite opseestools as:

Arroyo, O., Feliciano, D., Novoa, D., & Valcárcel, J. (2024). opseestools: A Python library to streamline OpenSeesPy workflows. SoftwareX, 27, 101832.

## Description and use 

ops tools comprises a set of functions in four categories:

1) 2D Analysis functions. This library is called analysis. You can import it as:

import opstools.analisis as an

2) 3D Analysis functions. This library is called analysis. You can import it as:

import opstools.analisis3D as an3D (or any name you want)

3) A set of utilities to support model building. You can import it as:

import opstools.utilidades as ut (or any other name)

4) A library to calculate and plot fragility functions. You can import it as:

import opstools.Lib_frag as lf (or any other name)

## Documentation and tutorials

The full documentation is available on the GitHub website: https://github.com/odarroyo/opseestools

Tutorials of how to use the functions are available in the examples folder in: https://github.com/odarroyo/opseestools 




